# GENERATED FILE - DO NOT EDIT
VERSION = '201802051227'
BUILDS = {'Darwin': {'sha256': '6fd4cae0d491fcc0cf96f6ef37e89aec35d435e7a6ac2b8d812fb8a66db8ef07',
            'url': 'http://s3-us-west-2.amazonaws.com/ai2-thor/builds/thor-201802051227-OSXIntel64.zip'},
 'Docker': {'tag': '201802051227'},
 'Linux': {'sha256': '4b10e4d6434585da9cf199198efabfbd49b1adbe2f421d794c848fc0f8a522f9',
           'url': 'http://s3-us-west-2.amazonaws.com/ai2-thor/builds/thor-201802051227-Linux64.zip'}}